<div>
<img class="left-align" src="{% static 'path/to/image@500px.png' %}" srcset="{% static 'path/to/image@200px.png' %} 200w, {% static 'path/to/image@400px.png' %} 400w" title="This is hover text" />
<p>This is the caption text.</p>
</div>
